Image
=====

.. currentmodule:: toasty.image

.. autoclass:: Image
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Image.default_format
      ~Image.dtype
      ~Image.height
      ~Image.mode
      ~Image.shape
      ~Image.wcs
      ~Image.width

   .. rubric:: Methods Summary

   .. autosummary::

      ~Image.asarray
      ~Image.aspil
      ~Image.clear
      ~Image.ensure_negative_parity
      ~Image.fill_into_maskable_buffer
      ~Image.flip_parity
      ~Image.from_array
      ~Image.from_pil
      ~Image.get_parity_sign
      ~Image.has_wcs
      ~Image.make_thumbnail_bitmap
      ~Image.save
      ~Image.update_into_maskable_buffer

   .. rubric:: Attributes Documentation

   .. autoattribute:: default_format
   .. autoattribute:: dtype
   .. autoattribute:: height
   .. autoattribute:: mode
   .. autoattribute:: shape
   .. autoattribute:: wcs
   .. autoattribute:: width

   .. rubric:: Methods Documentation

   .. automethod:: asarray
   .. automethod:: aspil
   .. automethod:: clear
   .. automethod:: ensure_negative_parity
   .. automethod:: fill_into_maskable_buffer
   .. automethod:: flip_parity
   .. automethod:: from_array
   .. automethod:: from_pil
   .. automethod:: get_parity_sign
   .. automethod:: has_wcs
   .. automethod:: make_thumbnail_bitmap
   .. automethod:: save
   .. automethod:: update_into_maskable_buffer
